# Serializer for Records

Parameters
----------

- name_file: str,
- records: List[Record],
- build: bool = False
        if `True`, builds the JSON file in the current directory with the given `name_file`.

Returns
-------
- str
        A JSON string representing the list of records.
        

```python

